@@ -15,7 +15,8 @@
 #' @param substyle (integer) The progress-bar substyle according to
 #' [pbmcapply::progressBar()].
 #'
-#' @param \ldots Additional arguments passed to [make_progression_handler()].
+#' @param \ldots Additional arguments passed to [pbmcapply::progressBar()]
+#' and [make_progression_handler()].
 #'
 #' @section Requirements:
 #' This progression handler requires the \pkg{pbmcapply} package.
@@ -80,13 +81,15 @@ handler_pbmcapply <- function(char = "=", substyle = 3L, style = "ETA", file = s
       if (!is.null(pb)) return(pb)
       
       ## SPECIAL CASE: pbmcapply::progressBar() does not support max == min
+      ## (its 'min' argument defaults to 0)
       if (max == 0) {
-        pb <- txtProgressBar()
-        class(pb) <- c("voidProgressBar", class(pb))
+        pb_tmp <- txtProgressBar()
+        class(pb_tmp) <- c("voidProgressBar", class(pb_tmp))
       } else {
         args <- c(list(max = max, ...), backend_args)
-        pb <<- do.call(progressBar, args = args)
+        pb_tmp <- do.call(progressBar, args = args)
       }
+      pb <<- pb_tmp
       
       pb
     }
@@ -107,7 +110,9 @@ handler_pbmcapply <- function(char = "=", substyle = 3L, style = "ETA", file = s
       },
 
       interrupt = function(config, state, progression, ...) {
-        msg <- getOption("progressr.interrupt.message", "interrupt detected")
+        eraseTxtProgressBar(pb)
+        redrawTxtProgressBar(pb)
+        msg <- conditionMessage(progression)
         msg <- paste(c("", msg, ""), collapse = "\n")
         cat(msg, file = file)
       },
@@ -121,6 +126,7 @@ handler_pbmcapply <- function(char = "=", substyle = 3L, style = "ETA", file = s
       update = function(config, state, progression, ...) {
         if (!state$enabled || config$times <= 2L) return()
         make_pb(max = config$max_steps, file = file)
+        stop_if_not(!is.null(pb))
         if (inherits(progression, "sticky")) {
           eraseTxtProgressBar(pb)
           message(paste0(state$message, ""))
